package com.autentia.tutoriales.spring.beanshell;

import org.junit.Assert;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.FileSystemXmlApplicationContext;

/**
 * Tests de verificación del cálculo de costes
 * @author Carlos García. Autentia
 * @see http://www.mobiletest.es
 */
public class CalculoCostesTest  {
	private ApplicationContext	factory;
	private final int PRECIO_PRODUCTO = 10;
	
	/**
	 * Inicializamos el contexto de Spring
	 */
	@org.junit.Before
	public void initTests(){
		factory  = new FileSystemXmlApplicationContext("applicationContext.xml");
	}
	
	/**
	 * @param numeroProductos Número de productos que tendrá el carrito
	 * @return Devuelve un carrito de compra con todos los productos al mismo precio
	 */
	private CarritoCompra getCarrito(int numeroProductos){
    	CarritoCompra carrito  = (CarritoCompra) factory.getBean("carrito");
    	Producto	  producto = null;
    	
    	for (int i = 0; i < numeroProductos; i++){
    		producto = (Producto) factory.getBean("producto");
    		producto.setPrecio(PRECIO_PRODUCTO);
    		carrito.addProduct(producto);
    	}
    	return carrito;
	}
	
	/**
	 * Test para verificar el cálculo del precio para un pedido CON descuento (Hay más de 9 productos)
	 */
    @org.junit.Test
    public void calculoConDescuento(){
    	final int	  NUMERO_PRODUCTOS = 20;
    	CarritoCompra carrito  = this.getCarrito(NUMERO_PRODUCTOS);
    	final double TOTAL	   = PRECIO_PRODUCTO * NUMERO_PRODUCTOS;
    	final double DESCUENTO = TOTAL - (TOTAL * 0.04);
    	
    	Assert.assertTrue(carrito.getPrecio() == DESCUENTO);
    }

	/**
	 * Test para verificar el cálculo del precio para un pedido SIN descuento (Hay menos de 9 productos)
	 */
    @org.junit.Test
    public void calculoSinDescuento(){
    	final int	  NUMERO_PRODUCTOS = 5;
    	CarritoCompra carrito  = this.getCarrito(NUMERO_PRODUCTOS);
    	Assert.assertTrue(carrito.getPrecio() == (PRECIO_PRODUCTO * NUMERO_PRODUCTOS));  	
    }    
}
